@@ -2,6 +2,7 @@ from typing import Union, Optional
 
 from datacode.models.dtypes.base import DataType
 from datacode.models.dtypes.bool_type import BooleanType
+from datacode.models.dtypes.date_type import DateType
 from datacode.models.dtypes.datetime_type import DatetimeType
 from datacode.models.dtypes.float_type import FloatType
 from datacode.models.dtypes.int_type import IntType
@@ -24,6 +25,7 @@ def convert_str_to_data_type_if_necessary(dtype: Union[str, DataType]) -> Option
 def convert_str_to_data_type(dtype: str) -> DataType:
     manager = DataTypeManager([
         BooleanType(),
+        DateType(),
         DatetimeType(),
         FloatType(),
         IntType(),
