@@ -11,7 +11,7 @@ class DatetimeType(DataType):
         super().__init__(
             datetime.datetime,
             pd_class=np.datetime64,
-            names=('datetime', 'date', 'time', 'datetime64'),
+            names=('datetime', 'time', 'datetime64'),
             categorical=categorical,
             ordered=ordered,
         )
